<?php

/**
 * Zosia: Plugin & theme Filters and actions
 *
 * @link http://www.3forty.media
 * @package Zosia
 */


// ========================================================
// Change location of TFM related posts
// ========================================================
if ( function_exists('tfm_related_posts') ) {

    remove_action( 'tfm_after_comments', 'tfm_related_posts', 10 );
    add_action( 'tfm_after_content', 'tfm_related_posts', 10 );

}

// ========================================================
// Related posts max cols 2
// ========================================================

function zosia_related_posts_max_cols() {

    return 2;

}
add_filter( 'tfm_related_posts_max_cols', 'zosia_related_posts_max_cols');

// ========================================================
// Change location of TFM header social for Logo left Header
// ========================================================

if ( function_exists('tfm_social_icons_theme_header') ) {

    if ( get_theme_mod( 'tfm_header_layout', 'default') === 'logo-left-menu-right' ) {

        remove_action( 'tfm_header_left', 'tfm_social_icons_theme_header', 10 );
        add_action( 'tfm_header_right', 'tfm_social_icons_theme_header', 40 );
        
    }

}

// ========================================================
// Change location of TFM Rating
// ========================================================
if ( function_exists( 'tfm_ratings')) {

    if ( ! is_single()  ) {
        remove_action( 'tfm_after_after_title_meta', 'tfm_ratings', 10 );
        add_action( 'tfm_after_entry_title', 'tfm_ratings', 20 );
    }
}

// ========================================================
// Check for Cover post style
// ========================================================

function tfm_cover_post_style() {

    $post_style = '';

    if ( ( is_home() || is_archive() || is_search() ) && in_array('cover', get_post_class( ) ) ) {
        $post_style = 'cover';
    }
    if ( is_single() && in_array('cover', get_post_class( ) ) && ! in_array('disabled-post-thumbnail', get_post_class( ) ) ) {
        $post_style = 'cover';
    }
    if ( is_single() && ( in_array('hero-default', get_post_class( ) ) || in_array('hero-cover', get_post_class( ) ) || in_array('default-alt', get_post_class( ) ) ) ) {
        $post_style = 'cover'; // Not actually but we use it for checks
    }
    if ( is_single() && false === in_array('has-post-media', get_post_class( ))) {
        $post_style = 'cover'; // Not actually but we use it for checks
    }
    $cover_style = 'cover' === $post_style ? true : false;

    return $cover_style;
}

// ========================================================
// Add share to archive posts
// ========================================================

/**
 *  Enable archive post share for this theme
 */

function zosia_enable_share_in_blog_lists() {

    if ( function_exists('tfm_share_content') ) {

        return true;

    }
}
add_filter( 'tfm_social_plugin_theme_supports_share_blog_list_posts', 'zosia_enable_share_in_blog_lists' ) ;

/**
 *  Remove default action
 */

if ( function_exists('tfm_share_archive_content')) {

    remove_action( 'tfm_after_after_title_meta', 'tfm_share_archive_content', 10 );

}

/**
 *  Add new conditional action (cover style)
 */

function zosia_cover_style_share() {

    if ( ! is_single() & tfm_cover_post_style() && function_exists('tfm_share_content') ) {
        tfm_share_archive_content( );
}
}
add_action( 'tfm_after_after_title_meta', 'zosia_cover_style_share', 20 );

// ========================================================
// Add header section opener default post style
// ========================================================
function zosia_default_post_style_header_section_open() {

    if ( false === tfm_cover_post_style() ) {
        echo '<div class="entry-header-section">';
    }

}
add_action( 'tfm_entry_header_open', 'zosia_default_post_style_header_section_open' );

// ========================================================
// Close header section wrapper default post style
// ========================================================
function zosia_default_post_style_header_section_close() {

    if ( false === tfm_cover_post_style() ) {
        echo '</div>';
    }

}
add_action( 'tfm_after_entry_title', 'zosia_default_post_style_header_section_close', 100 );

// ========================================================
// Filter entry meta data
// ========================================================
function zosia_entry_meta_data() {

    // Just show avatar for default format
    if ( false === tfm_cover_post_style() ) {

        return array( 'author_avatar', 'social' );

    } else {

        // Return default args to prevent an empty array loop
        return array('author_avatar', 'author', 'date', 'updated_date', 'comment_count', 'read_time');
        
    }
}
add_filter( 'tfm_entry_meta_data', 'zosia_entry_meta_data', 10);

// ========================================================
// Display custom meta data for default format
// ========================================================

function zosia_after_title_meta() {

    if ( false === tfm_cover_post_style() ) {

        tfm_get_entry_meta( array( 'author_avatar', 'author', 'date', 'updated_date', 'comment_count', 'read_time' ), $has_wrapper = true, $has_container = true, $html_style = 'li', $meta_wrapper_class = 'entry-meta tfm-meta', $meta_class = 'after-title-meta tfm-after-title-meta' );
    }
}
add_action( 'tfm_after_entry_title', 'zosia_after_title_meta', 10 );


// ========================================================
// TFM posts widget max meta item count before break
// ========================================================

function zosia_tfm_posts_widget_meta_item_count_max() {
    return 5;
}
add_filter( 'tfm_posts_widget_meta_item_count_max', 'zosia_tfm_posts_widget_meta_item_count_max', 10 );

// ========================================================
// Max colums for list layout
// ========================================================

function zosia_max_post_cols_list() {
    return 2;
}
add_filter( 'tfm_max_post_cols_list', 'zosia_max_post_cols_list' );

// w/sidebar
function zosia_max_post_cols_list_width_sidebar() {
    return 1;
}
add_filter( 'tfm_max_post_cols_list_width_sidebar', 'zosia_max_post_cols_list_width_sidebar' );

// ========================================================
// TFM Featured posts
// ========================================================

// Add support for featured posts
function zosia_theme_supports_featured_posts() {
    return true;
}
add_filter( 'tfm_theme_supports_featured_posts', 'zosia_theme_supports_featured_posts' );

// Remove default action
if ( function_exists('tfm_featured_posts')) {
    remove_action( 'tfm_after_header', 'tfm_featured_posts', 20 );
}

// ========================================================
// TFM Remove support for full width posts
// ========================================================

function zosia_remove_full_width_post_support() {
    return false;
}
add_filter( 'tfm_theme_supports_full_width_posts', 'zosia_remove_full_width_post_support' );

// ========================================================
// TFM Remove support for featured post colours
// ========================================================

function zosia_theme_supports_featured_post_misc_colors() {
    return false;
}
add_filter( 'tfm_theme_supports_featured_post_misc_colors', 'zosia_theme_supports_featured_post_misc_colors' );

// ========================================================
// TFM Hero Add header section opener default post style
// ========================================================
function zosia_tfm_hero_default_post_style_header_section_open() {

    if ( 'cover' !== get_theme_mod( 'tfm_hero_style', 'default') ) {
        echo '<div class="entry-header-section">';
    }

}
add_action( 'tfm_hero_entry_header_open', 'zosia_tfm_hero_default_post_style_header_section_open' );

// ========================================================
// TFM Hero Close header section wrapper default post style
// ========================================================
function zosia_tfm_hero_default_post_style_header_section_close() {

    if ( 'cover' !== get_theme_mod( 'tfm_hero_style', 'default') ) {
        echo '</div>';
    }

}
add_action( 'tfm_hero_after_entry_title', 'zosia_tfm_hero_default_post_style_header_section_close', 100 );

// ========================================================
// TFM Hero Filter entry meta data
// ========================================================
function zosia_tfm_hero_entry_meta_data() {

     if ( 'cover' !== get_theme_mod( 'tfm_hero_style', 'default') ) {

        return array( 'author_avatar' );

    } else {

        // Return default args to prevent an empty array loop
        return array('author_avatar', 'author', 'date', 'comment_count', 'read_time') ;
        
    }
}
add_filter( 'tfm_hero_entry_meta_data', 'zosia_tfm_hero_entry_meta_data', 10 );

// ========================================================
// Remove avatar from after title meta
// ========================================================

function zosia_tfm_hero_after_title_meta() {

    if ( function_exists('tfm_hero')) :

        include( TFM_HERO__PLUGIN_DIR . 'inc/vars.php' );

        if ( 'cover' !== get_theme_mod( 'tfm_hero_style', 'default') ) {

            echo '<div class="entry-meta tfm-meta" ' . wp_kses_post( $custom_color['entry_meta'] ) . '><ul class="after-title-meta tfm-after-title-meta">';
            tfm_hero_get_entry_meta( array( 'author_avatar', 'author', 'date', 'comment_count', 'read_time') );
            echo '</ul></div>';
        }

    endif;
}
add_action( 'tfm_hero_after_entry_title', 'zosia_tfm_hero_after_title_meta', 10 );

// ========================================================
// TFM Related posts Add header section opener default post style
// ========================================================
function zosia_tfm_related_posts_default_post_style_header_section_open() {

    if ( 'cover' !== get_theme_mod( 'tfm_related_posts_style', 'default') ) {
        echo '<div class="entry-header-section">';
    }

}
add_action( 'tfm_related_posts_entry_header_open', 'zosia_tfm_related_posts_default_post_style_header_section_open' );

// ========================================================
// TFM Related Posts Close header section wrapper default post style
// ========================================================
function zosia_tfm_related_posts_default_post_style_header_section_close() {

    if ( 'cover' !== get_theme_mod( 'tfm_related_posts_style', 'default') ) {
        echo '</div>';
    }

}
add_action( 'tfm_related_posts_after_entry_title', 'zosia_tfm_related_posts_default_post_style_header_section_close', 100 );

// ========================================================
// TFM Related Posts Filter entry meta data
// ========================================================
function zosia_tfm_related_posts_entry_meta_data() {

     if ( 'cover' !== get_theme_mod( 'tfm_related_posts_style', 'default') ) {

        return array( 'author_avatar' );

    } else {

        // Return default args to prevent an empty array loop
        return array('author_avatar', 'author', 'date', 'comment_count', 'read_time') ;
        
    }
}
add_filter( 'tfm_related_posts_entry_meta_data', 'zosia_tfm_related_posts_entry_meta_data', 10 );

// ========================================================
// TFM Related Posts Remove avatar from after title meta
// ========================================================

function zosia_tfm_related_posts_after_title_meta() {

    if ( 'cover' !== get_theme_mod( 'tfm_related_posts_style', 'default') ) {

        echo '<div class="entry-meta tfm-meta"><ul class="after-title-meta tfm-after-title-meta">';
        tfm_related_posts_get_entry_meta( array( 'author_avatar', 'author', 'date', 'comment_count', 'read_time') );
        echo '</ul></div>';
    }
}
add_action( 'tfm_related_posts_after_entry_title', 'zosia_tfm_related_posts_after_title_meta', 10 );

// ========================================================
// Remove avatar support in widgets
// ========================================================

function zosia_tfm_posts_widget_avatar_support() {
    return false;
}
add_filter( 'tfm_posts_widget_theme_supports_avatar', 'zosia_tfm_posts_widget_avatar_support', 10 );
add_filter( 'tfm_featured_posts_theme_supports_avatar', 'zosia_tfm_posts_widget_avatar_support', 10 );

// ========================================================
// Remove customizer controls, sections and panels
// ========================================================
function zosia_remove_customizer_optons( $wp_customize ) {

    // Remove controls
    $wp_customize->remove_control('tfm_post_format_icons');

    // Remove meta controls
    $wp_customize->remove_control('tfm_archive_entry_meta_in');
    $wp_customize->remove_control('tfm_homepage_entry_meta_in');
    $wp_customize->remove_control('tfm_single_entry_meta_in');
    $wp_customize->remove_control('tfm_image_format_entry_meta_in');
    $wp_customize->remove_control('tfm_related_posts_entry_meta_in');

    // Remove human readable date controls
    $wp_customize->remove_control('tfm_human_entry_date');
    $wp_customize->remove_control('tfm_human_comment_date');


    // Remove tfm hero controls
    $wp_customize->remove_control('tfm_hero_margins');
    $wp_customize->remove_control('tfm_hero_entry_meta_in');
    $wp_customize->remove_control('tfm_hero_post_count');
    $wp_customize->remove_control('tfm_hero_button_background');
    $wp_customize->remove_control('tfm_hero_count_background');
    $wp_customize->remove_control('tfm_hero_count_color');
    $wp_customize->remove_control('tfm_hero_avatar_border_color');
    // Ratings
    $wp_customize->remove_control('tfm_hero_ratings_separator');
    $wp_customize->remove_control('tfm_hero_ratings_info');
    $wp_customize->remove_control('tfm_hero_tfm_star_rating');
    $wp_customize->remove_control('tfm_hero_tfm_scale_rating');
    $wp_customize->remove_control('tfm_hero_tfm_points_rating');
    $wp_customize->remove_control('tfm_hero_tfm_percent_rating');
    $wp_customize->remove_control('tfm_hero_tfm_stars_color');

    // Remove tfm related posts ratings
    $wp_customize->remove_control('tfm_related_posts_ratings_separator');
    $wp_customize->remove_control('tfm_related_posts_ratings_info');
    $wp_customize->remove_control('tfm_related_posts_tfm_star_rating');
    $wp_customize->remove_control('tfm_related_posts_tfm_scale_rating');
    $wp_customize->remove_control('tfm_related_posts_tfm_points_rating');
    $wp_customize->remove_control('tfm_related_posts_tfm_percent_rating');
    $wp_customize->remove_control('tfm_related_posts_tfm_stars_color');

if ( function_exists('tfm_hero')) :

    $wp_customize->get_control( 'tfm_hero_layout' )->choices = array(
         'grid' => esc_html__( 'Grid', 'zosia' ),
         'slider' => esc_html__( 'Slider', 'zosia' ),
        );

    $wp_customize->get_control( 'tfm_hero_style' )->choices = array(
         'default' => esc_html__( 'Default', 'zosia' ),
         'cover' => esc_html__( 'Cover', 'zosia' ),
        );

endif;

}
add_action( 'customize_register', 'zosia_remove_customizer_optons', 100 );

// ========================================================
// Unregister plugin sidebars
// ========================================================
function zosia_unregister_sidebars(){

    if (function_exists('tfm_theme_boost_init')) :
 
        unregister_sidebar( 'after-header-sidebar' );
        unregister_sidebar( 'site-header-sidebar' );

    endif;

}
add_action( 'widgets_init', 'zosia_unregister_sidebars', 11 );




