<?php

/**
 * Template variables
 *
 * @package WordPress
 * @subpackage Zosia
 * @since 1.0
 * @version 1.2
 */

if ( ! function_exists( 'tfm_template_vars' ) ) {

	function tfm_template_vars( $template = '', $args = false ) {

		$faux_count = isset($args['faux_count']) ? $args['faux_count'] : null;
		$true_count = isset($args['count']) ? $args['count'] : null;

		global $post;
		global $wp_query;


		$queried_object = get_queried_object();
		$post_count = $wp_query->found_posts;

		$post_layout = tfm_get_post_layout();
		$post_cols = tfm_get_post_cols( 'count' );

		// ========================================================
		// Content
		// ========================================================

		$in_loop_widget_position = is_home() ? get_theme_mod( 'tfm_homepage_loop_sidebar_position', '' ) : get_theme_mod( 'tfm_archive_loop_sidebar_position', '' );

		$faux_class = 'faux-count-' . $faux_count;
		$faux_class .= ( $post_layout === 'grid-first-full' && $true_count === 1 && 1 !== $in_loop_widget_position ? ' first-full' : '' );
		$faux_class .= 'grid-asc' === $post_layout  && $faux_count === 1 || 'grid-desc' === $post_layout  && ( ( $post_cols === 2 && $faux_count === 3 ) || ( $post_cols === 3 && $faux_count === 6 ) || ( $post_cols === 4 && $faux_count === 10 ) ) ? ' asc-desc-full-width' : '';
		$cover_wrapper = ( ( is_single() || is_page() ) && in_array('cover', get_post_class( ) ) && ! in_array('disabled-post-thumbnail', get_post_class( )) ? true : false );
		$disabled_thumbnail = ( in_array('disabled-post-thumbnail', get_post_class()) ? true : false );
		$thumbnail_size = ( $args && $args['count'] ? $args['count'] : '' );
		$figcaption = ( is_single() && ! $cover_wrapper && get_post( get_post_thumbnail_id() )->post_excerpt ? ' has-figcaption' : false );

		//
		// Post style
		//

		$post_style = ( is_home() ? get_theme_mod( 'tfm_homepage_loop_style', 'default' ) : get_theme_mod( 'tfm_archive_loop_style', 'default' )  );
		if ( ! is_single() && has_post_format( 'image') ) {
			$post_style = 'cover';
		}
		if ( has_post_format( 'video' ) || has_post_format( 'audio') || has_post_format( 'gallery' ) ) {
			$post_style = 'default';
		}
		if ( is_single() ) {
			if ( function_exists('tfm_custom_meta_box') && get_post_meta( get_the_ID(), 'tfm_single_post_style', true ) && get_post_meta( get_the_ID(), 'tfm_single_post_style', true ) !== 'global' ) {
				$post_style = get_post_meta( get_the_ID(), 'tfm_single_post_style', true );
			} else {
				$post_style = get_theme_mod( 'tfm_single_post_style', 'default' );
			}
		}
		if ( is_page() ) {
			$post_style = get_theme_mod( 'tfm_page_style', 'default' );
		}

		//
		// Entry Title
		//

		$entry_title = ( is_home() ? get_theme_mod( 'tfm_homepage_entry_title', true ) : get_theme_mod( 'tfm_archive_entry_title', true ) );
		if  ( has_post_format( 'image' ) && false === get_theme_mod( 'tfm_image_format_use_global', true ) ) {
			$entry_title = get_theme_mod( 'tfm_image_format_entry_title', true );
		}

		//
		// Full width
		//

		$full_width = ( ( is_single() && get_theme_mod( 'tfm_single_full_width', false ) && 'cover' !== get_theme_mod( 'tfm_single_post_style', 'default' ) ) || ( is_page() && get_theme_mod( 'tfm_page_full_width', false ) && 'cover' !== get_theme_mod( 'tfm_page_style', 'default' ) ) ? ' alignfull' : '' );
		if ( is_single( ) && '' === $full_width && function_exists('tfm_custom_meta_box') && get_post_meta( get_the_ID(), 'tfm_single_full_width', true ) ) {
			$full_width = ' alignfull';
		}
		$full_width_cover = ( ( is_single() && get_theme_mod( 'tfm_single_full_width', false ) && 'cover' === get_theme_mod( 'tfm_single_post_style', 'default' ) ) || ( is_page() && get_theme_mod( 'tfm_page_full_width', false ) && 'cover' === get_theme_mod( 'tfm_page_style', 'default' ) ) ? ' alignfull' : '' );
		if ( is_single( ) && '' === $full_width_cover && function_exists('tfm_custom_meta_box') && get_post_meta( get_the_ID(), 'tfm_single_full_width', true ) ) {
			$full_width_cover = ' alignfull';
		}
		// ========================================================
		// Pagination
		// ========================================================
		$show_pagination_numbers = ( get_theme_mod( 'tfm_pagination_numbers', false ) ? ' has-pagination-numbers' : '' );
		$show_pagination_prev_next = ( get_theme_mod( 'tfm_pagination_prev_next', true ) ? ' has-pagination-prev-next' : '' );

		// ========================================================
		// Header
		// ========================================================

		$sticky_nav = ( get_theme_mod( 'tfm_sticky_nav', false ) ? ' sticky-nav' : '' );
		$sticky_mobile_nav = ( get_theme_mod( 'tfm_sticky_nav_mobile', false ) ? ' sticky-mobile-nav' : '' );
		$header_size = ( get_theme_mod( 'tfm_header_full_width', false) ? ' fullwidth' : '' );
		$header_search_input = ( get_theme_mod( 'tfm_header_search_input', false) ? ' has-search-input' : '' );
		$header_primary_nav = ( has_nav_menu( 'primary' ) ? ' has-primary-nav' : '' );
		$header_secondary_nav = ( has_nav_menu( 'header-secondary' ) ? ' has-secondary-nav' : '' );
		$header_secondary_nav_mobile = ( has_nav_menu( 'header-secondary-mobile' ) ? ' has-secondary-nav' : '' );
		$header_third_nav = ( has_nav_menu( 'header-third' ) ? ' has-third-nav' : '' );
		$header_split_menu = ( 'logo-split-menu' === get_theme_mod( 'tfm_header_layout', 'default' ) && has_nav_menu( 'split-menu-left' ) ? ' has-split-menu-left' : '' );
		$header_split_menu .= ( 'logo-split-menu' === get_theme_mod( 'tfm_header_layout', 'default' ) && has_nav_menu( 'split-menu-right' ) ? ' has-split-menu-right' : '' );
		$header_toggle_icons = ( get_theme_mod( 'tfm_toggle_menu', true ) ? ' has-toggle-menu' : '' );
		$header_toggle_icons .= ( get_theme_mod( 'tfm_toggle_search', true ) ? ' has-toggle-search' : '' );
		$header_social_icons = function_exists('tfm_social_icons_theme_header') && get_theme_mod( 'tfm_header_social', false ) ? ' has-tfm-social-icons' : '';
		$header_background = '' !== get_theme_mod( 'tfm_header_background_color', '' ) ? ' has-background' : '';
		$header_primary_nav_background = '' !== get_theme_mod( 'tfm_primary_nav_background', '' ) ? ' has-primary-nav-background' : '';


		// ========================================================
		// Sidebar
		// ========================================================

		$sidebar = '';
		if ( current_theme_supports( 'woocommerce') && class_exists('WooCommerce')) {
			if ( is_page( 'cart' ) || is_page( 'checkout') || is_page( 'basket' ) || is_account_page() ) {
				$sidebar = 'shop';
			}

		}

		return array(
			'show_pagination_numbers' => $show_pagination_numbers,
			'show_pagination_prev_next' => $show_pagination_prev_next,
			'post_count' => $post_count,
			'object' => $queried_object,
			'sticky_nav' => $sticky_nav,
			'sticky_mobile_nav' => $sticky_mobile_nav,
			'header_size' => $header_size,
			'header_search_input' => $header_search_input,
			'header_toggle_icons' => $header_toggle_icons,
			'header_primary_nav' => $header_primary_nav,
			'header_secondary_nav' => $header_secondary_nav,
			'header_secondary_nav_mobile' => $header_secondary_nav_mobile,
			'header_third_nav' => $header_third_nav,
			'header_split_menu' => $header_split_menu,
			'header_social_icons' => $header_social_icons,
			'header_background' => $header_background,
			'header_primary_nav_background' => $header_primary_nav_background,
			'sidebar' => $sidebar,
			'content' => array(
				'faux_class' => $faux_class,
				'cover_wrapper' => $cover_wrapper,
				'disabled_thumbnail' => $disabled_thumbnail,
				'thumbnail_size' => $thumbnail_size,
				'figcaption' => $figcaption,
				'entry_title' => $entry_title,
				'post_style' => $post_style,
				'full_width' => array(
					'cover' => $full_width_cover,
					'default' => $full_width,
				),
			),
		);

	}

} ?>